# Support and Help

Need help for getting started or using a project? Here's how.

## How to get help

Generally, we do not use GitHub as a support forum. For any usage questions that are not specific to the project itself, please check [Stack Overflow](https://stackoverflow.com) or ask some AI instead. By doing so, you are more likely to quickly solve your problem, and you will allow anyone else with the same question to find the answer (going SO's way). This also allows maintainers to focus on improving the project for others.

Now, in case of having some issue with the project itself please seek support in the following ways:

1. **Read the project's documentation and other guides** to check if you can figure it out on your own. These are located under [this URL](https://LucasGoncSilva.github.io/mosheh); everything you may need to know about Mosheh is going to be there.
1. **Search for answers and ask questions on [Stack Overflow](https://stackoverflow.com).** This is the most appropriate place for debugging issues specific to your use of the project, or figuring out how to use the project in a specific way.
1. As a **last resort**, you may open an issue on GitHub to ask for help. However, please clearly explain what you are trying to do, and list what you have already attempted to solve the problem. Provide code samples, but **do not** attach your entire project for someone else to debug.

## What NOT to do

Please **do not** do any the following:

1. Do not reach out to the author or contributor on X (or other social media) by tweeting or sending a direct message.
1. Do not email the author or contributor.
1. Do not open duplicate issues or comment an existing issue with "+1"; use emojis instead.

These are not appropriate avenues for seeking help or support with an open-source project. Please follow the guidelines in the previous section. Public questions get public answers, which benefits everyone in the community.

## Customer Support

I do not provide any sort of "customer support" for open-source projects individually. However, if you wanna talk about some work to get done visit [lucasgonc.vercel.app](https://lucasgonc.vercel.app/).
